@@ -1,32 +1,7 @@
 #
-# [The "BSD license"]
-#  Copyright (c) 2012 Terence Parr
-#  Copyright (c) 2012 Sam Harwell
-#  Copyright (c) 2014 Eric Vergnaud
-#  All rights reserved.
-#
-#  Redistribution and use in source and binary forms, with or without
-#  modification, are permitted provided that the following conditions
-#  are met:
-#
-#  1. Redistributions of source code must retain the above copyright
-#     notice, this list of conditions and the following disclaimer.
-#  2. Redistributions in binary form must reproduce the above copyright
-#     notice, this list of conditions and the following disclaimer in the
-#     documentation and/or other materials provided with the distribution.
-#  3. The name of the author may not be used to endorse or promote products
-#     derived from this software without specific prior written permission.
-#
-#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-#  IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-#  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-#  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-#  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-#  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-#  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-#  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-#  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+# Copyright (c) 2012-2016 The ANTLR Project. All rights reserved.
+# Use of this file is governed by the BSD 3-clause license that
+# can be found in the LICENSE.txt file in the project root.
 #
 
 # A tree structure used to record the semantic context in which
@@ -85,7 +60,7 @@ class SemanticContext(object):
 
     def __str__(self):
         return unicode(self)
-    
+
     def __unicode__(self):
         return unicode(super(SemanticContext, self))
 
@@ -115,14 +90,7 @@ def orContext(a, b):
         return result
 
 def filterPrecedencePredicates(collection):
-    result = []
-    for context in collection:
-        if isinstance(context, PrecedencePredicate):
-            if result is None:
-                result = []
-            result.append(context)
-    return result
-
+    return [context for context in collection if isinstance(context, PrecedencePredicate)]
 
 class Predicate(SemanticContext):
 
@@ -187,13 +155,11 @@ class AND(SemanticContext):
     def __init__(self, a, b):
         operands = set()
         if isinstance( a, AND):
-            for o in a.opnds:
-                operands.add(o)
+            operands.update(a.opnds)
         else:
             operands.add(a)
         if isinstance( b, AND):
-            for o in b.opnds:
-                operands.add(o)
+            operands.update(b.opnds)
         else:
             operands.add(b)
 
@@ -203,7 +169,7 @@ class AND(SemanticContext):
             reduced = min(precedencePredicates)
             operands.add(reduced)
 
-        self.opnds = [ o for o in operands ]
+        self.opnds = list(operands)
 
     def __eq__(self, other):
         if self is other:
@@ -227,10 +193,7 @@ class AND(SemanticContext):
     # unordered.</p>
     #
     def eval(self, parser, outerContext):
-        for opnd in self.opnds:
-            if not opnd.eval(parser, outerContext):
-                return False
-        return True
+        return all(opnd.eval(parser, outerContext) for opnd in self.opnds)
 
     def evalPrecedence(self, parser, outerContext):
         differs = False
@@ -277,13 +240,11 @@ class OR (SemanticContext):
     def __init__(self, a, b):
         operands = set()
         if isinstance( a, OR):
-            for o in a.opnds:
-                operands.add(o)
+            operands.update(a.opnds)
         else:
             operands.add(a)
         if isinstance( b, OR):
-            for o in b.opnds:
-                operands.add(o)
+            operands.update(b.opnds)
         else:
             operands.add(b)
 
@@ -291,10 +252,10 @@ class OR (SemanticContext):
         if len(precedencePredicates)>0:
             # interested in the transition with the highest precedence
             s = sorted(precedencePredicates)
-            reduced = s[len(s)-1]
+            reduced = s[-1]
             operands.add(reduced)
 
-        self.opnds = [ o for o in operands ]
+        self.opnds = list(operands)
 
     def __eq__(self, other):
         if self is other:
@@ -315,10 +276,7 @@ class OR (SemanticContext):
     # unordered.</p>
     #
     def eval(self, parser, outerContext):
-        for opnd in self.opnds:
-            if opnd.eval(parser, outerContext):
-                return True
-        return False
+        return any(opnd.eval(parser, outerContext) for opnd in self.opnds)
 
     def evalPrecedence(self, parser, outerContext):
         differs = False
