@@ -1,3 +1,8 @@
+#
+# Copyright (c) 2012-2016 The ANTLR Project. All rights reserved.
+# Use of this file is governed by the BSD 3-clause license that
+# can be found in the LICENSE.txt file in the project root.
+#
 
 #
 # Represent a subset of XPath XML path syntax for use in identifying nodes in
@@ -289,12 +294,7 @@ class XPathRuleElement(XPathElement):
 
     def evaluate(self, t):
         # return all children of t that match nodeName
-        nodes = []
-        for c in Trees.getChildren(t):
-            if isinstance(c, ParserRuleContext ):
-                if (c.ruleIndex == self.ruleIndex ) == (not self.invert):
-                    nodes.append(c)
-        return nodes
+        return [c for c in Trees.getChildren(t) if isinstance(c, ParserRuleContext) and (c.ruleIndex == self.ruleIndex) == (not self.invert)]
 
 class XPathTokenAnywhereElement(XPathElement):
 
@@ -314,12 +314,8 @@ class XPathTokenElement(XPathElement):
 
     def evaluate(self, t):
         # return all children of t that match nodeName
-        nodes = []
-        for c in Trees.getChildren(t):
-            if isinstance(c, TerminalNode):
-                if (c.symbol.type == self.tokenType ) == (not self.invert):
-                    nodes.append(c)
-        return nodes
+        return [c for c in Trees.getChildren(t) if isinstance(c, TerminalNode) and (c.symbol.type == self.tokenType) == (not self.invert)]
+
 
 class XPathWildcardAnywhereElement(XPathElement):
 
@@ -343,4 +339,4 @@ class XPathWildcardElement(XPathElement):
         if self.invert:
             return list() # !* is weird but valid (empty)
         else:
-            return Trees.getChildren(t)
\ No newline at end of file
+            return Trees.getChildren(t)
